==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_61.js <==
var searchData=
[
  ['activestate',['ActiveState',['../plplotter_8c.html#aa1f3f2a24a744225a06bdfbb13c6764f',1,'plplotter.c']]],
  ['addcoord',['addcoord',['../plfill_8c.html#aa13a4d397cdfb55d694f502e6276f663',1,'plfill.c']]],
  ['addframe',['AddFrame',['../classwxPLplotApp.html#a3e8e60fac4a602d74df8c62feda9fe8e',1,'wxPLplotApp']]],
  ['addtoclipregion',['AddtoClipRegion',['../classwxPLDevBase.html#a321df768f5cd7c0e14bf5a774dca6340',1,'wxPLDevBase']]],
  ['adv',['adv',['../classplstream.html#ab7f5e5c91c441fc52d4e19289780a2b2',1,'plstream::adv()'],['../classplplot_1_1core_1_1PLStream.html#a2c4bf70b9209691f579bf4b7a9b25c92',1,'plplot.core.PLStream.adv()']]],
  ['alloc2d',['alloc2d',['../csa_8c.html#afecb8e7c2408bf2e4d8a7819ca5449e2',1,'csa.c']]],
  ['alloc2dgrid',['Alloc2dGrid',['../classplstream.html#aa5552169469a3f9cc841311b13272992',1,'plstream']]],
  ['alloc_5flevel',['alloc_level',['../plcont_8c.html#a1c7f6939737f57ed1e5279c5cf7fd07c',1,'plcont.c']]],
  ['alloc_5fline',['alloc_line',['../plcont_8c.html#acfcf6b643b077801bb5a1b5529ce224d',1,'plcont.c']]],
  ['append_5fcmdlist',['Append_Cmdlist',['../tclAPI_8c.html#ac48c3efba7bcd2380c847607918537db',1,'tclAPI.c']]],
  ['appinit',['AppInit',['../pltcl_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;pltcl.c'],['../plserver_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;plserver.c']]],
  ['arc',['arc',['../classplstream.html#a2df216bc3bcfb93557a580f9db97d31c',1,'plstream::arc()'],['../classplplot_1_1core_1_1PLStream.html#a4eec09856b551b3e7f060ba97b5c045f',1,'plplot.core.PLStream.arc()'],['../cairo_8c.html#aed9756e3af7c349312e9663cc0f94d30',1,'arc():&#160;cairo.c']]],
  ['argv_5fto_5fchars',['argv_to_chars',['../tclAPI_8c.html#a465b6793aabf98ab5a98a2c6ee731cc3',1,'tclAPI.c']]],
  ['argv_5fto_5fdoubles',['argv_to_doubles',['../tclAPI_8c.html#a745a6beb32ab13d604771663d1d2179a',1,'tclAPI.c']]],
  ['argv_5fto_5fints',['argv_to_ints',['../tclAPI_8c.html#a623e8233b572bc4f359b041a18ea93ae',1,'tclAPI.c']]],
  ['art_5fdrect_5fhacktext',['art_drect_hacktext',['../plplotcanvas-hacktext_8c.html#ac4f986ee6129bf458b5ea277579be5ef',1,'plplotcanvas-hacktext.c']]],
  ['as_5fvalue',['as_value',['../classoctave__swig__type.html#a28b6ab346ab6b2070e1f79b2b8125e32',1,'octave_swig_type']]],
  ['assign',['assign',['../classoctave__swig__type.html#a79f184d20bef4691ffd0b61eceddd6cc',1,'octave_swig_type::assign(const std::string &amp;name, const octave_value &amp;ov)'],['../classoctave__swig__type.html#a432ff2f024024be845b1342e36bc7502',1,'octave_swig_type::assign(const std::string &amp;name, const swig_octave_member *m)']]],
  ['axes',['axes',['../classplstream.html#aae9c3ed421ec29c56c6a1ea0767ea0d4',1,'plstream::axes()'],['../classplplot_1_1core_1_1PLStream.html#abedfa8532b2bfea1adc596e39e7be4d7',1,'plplot.core.PLStream.axes()']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_61.js <==
var searchData=
[
  ['access',['access',['../plfreetype_8c.html#a694e04c2c93271c787470ba441cc1d98',1,'plfreetype.c']]],
  ['activestate',['ActiveState',['../plplotter_8c.html#aa1f3f2a24a744225a06bdfbb13c6764f',1,'plplotter.c']]],
  ['addcoord',['addcoord',['../plfill_8c.html#aa13a4d397cdfb55d694f502e6276f663',1,'plfill.c']]],
  ['adv',['adv',['../classplstream.html#ab7f5e5c91c441fc52d4e19289780a2b2',1,'plstream::adv()'],['../classplplot_1_1core_1_1PLStream.html#a2c4bf70b9209691f579bf4b7a9b25c92',1,'plplot.core.PLStream.adv()']]],
  ['alloc2d',['alloc2d',['../csa_8c.html#afecb8e7c2408bf2e4d8a7819ca5449e2',1,'csa.c']]],
  ['alloc2dgrid',['Alloc2dGrid',['../classplstream.html#aa5552169469a3f9cc841311b13272992',1,'plstream']]],
  ['alloc_5flevel',['alloc_level',['../plcont_8c.html#a1c7f6939737f57ed1e5279c5cf7fd07c',1,'plcont.c']]],
  ['alloc_5fline',['alloc_line',['../plcont_8c.html#acfcf6b643b077801bb5a1b5529ce224d',1,'plcont.c']]],
  ['alternate_5funicode_5fprocessing',['alternate_unicode_processing',['../plcore_8c.html#a684791a3ca4a8011f221eeb3d36181f2',1,'plcore.c']]],
  ['appendbuffer',['AppendBuffer',['../classwxPLplotstream.html#a69f96936f5c904e0b1452f118a152200',1,'wxPLplotstream']]],
  ['appendflt',['appendflt',['../plmap_8c.html#aed1a69ce9638d5330956c10d9165b3e7',1,'plmap.c']]],
  ['appendfltptr',['appendfltptr',['../plmap_8c.html#a81beb14e5b4371ad18b8ea3e8a86c654',1,'plmap.c']]],
  ['appendint',['appendint',['../plmap_8c.html#a6c1100974f916b51c213b9b27fd6879f',1,'plmap.c']]],
  ['appinit',['AppInit',['../pltcl_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;pltcl.c'],['../plserver_8c.html#a7b665803780f12d53cbccad6dbcfc689',1,'AppInit(Tcl_Interp *interp):&#160;plserver.c']]],
  ['aquire',['aquire',['../classPLNamedMutex.html#a8498a3e3bbf6e2905fa7b936f8a03eb8',1,'PLNamedMutex::aquire()'],['../classPLNamedMutex.html#a3cdaca8dab31100d2a660cdc392f5d7b',1,'PLNamedMutex::aquire(unsigned long millisecs)']]],
  ['aquirenowait',['aquireNoWait',['../classPLNamedMutex.html#a283bb66e2a98324a5e070f2df3d8c4e4',1,'PLNamedMutex']]],
  ['arc',['arc',['../classplstream.html#a2df216bc3bcfb93557a580f9db97d31c',1,'plstream::arc()'],['../classplplot_1_1core_1_1PLStream.html#a4eec09856b551b3e7f060ba97b5c045f',1,'plplot.core.PLStream.arc()'],['../cairo_8c.html#aed9756e3af7c349312e9663cc0f94d30',1,'arc():&#160;cairo.c']]],
  ['argv_5fto_5fchars',['argv_to_chars',['../tclAPI_8c.html#a465b6793aabf98ab5a98a2c6ee731cc3',1,'tclAPI.c']]],
  ['argv_5fto_5fdoubles',['argv_to_doubles',['../tclAPI_8c.html#a745a6beb32ab13d604771663d1d2179a',1,'tclAPI.c']]],
  ['argv_5fto_5fints',['argv_to_ints',['../tclAPI_8c.html#a623e8233b572bc4f359b041a18ea93ae',1,'tclAPI.c']]],
  ['as_5fvalue',['as_value',['../classoctave__swig__type.html#a28b6ab346ab6b2070e1f79b2b8125e32',1,'octave_swig_type']]],
  ['assign',['assign',['../classoctave__swig__type.html#a79f184d20bef4691ffd0b61eceddd6cc',1,'octave_swig_type::assign(const std::string &amp;name, const octave_value &amp;ov)'],['../classoctave__swig__type.html#a432ff2f024024be845b1342e36bc7502',1,'octave_swig_type::assign(const std::string &amp;name, const swig_octave_member *m)']]],
  ['axes',['axes',['../classplstream.html#aae9c3ed421ec29c56c6a1ea0767ea0d4',1,'plstream::axes()'],['../classplplot_1_1core_1_1PLStream.html#abedfa8532b2bfea1adc596e39e7be4d7',1,'plplot.core.PLStream.axes()']]]
];
